@@ -3,7 +3,7 @@ from matplotlib.animation import FuncAnimation
 import numpy as np
 
 
-def draw(fig, t, x, fs):
+def draw(fig, t, x, fs, interval, frames):
     class FourierSeries:
         def __init__(self, ft, fx, ffs):
             self.lines, = (plt.plot([], [], lw=3))
@@ -30,7 +30,7 @@ def draw(fig, t, x, fs):
     anim = FuncAnimation(fig,
                          animate,
                          fargs=[fourier],
-                         frames=10,
-                         interval=150,
+                         frames=frames,
+                         interval=interval,
                          blit=True)
     return anim
